@@ -78,7 +78,7 @@ class HubzeroDatabaseConnection(object):
       try:
         self.__class__.db = MySQLdb.connect(host=mysql_host, user=mysql_user, passwd=mysql_password, db=mysql_db)
       except:
-        self.env.log.error('HubzeroDatabaseConnection::connect() Failed: host %s user %s password %s db %s' % (mysql_host, mysql_user, mysql_password, mysql_db))
+        self.env.log.error('HubzeroDatabaseConnection::connect() Failed: host %s user %s password XXXXX db %s' % (mysql_host, mysql_user, mysql_db))
         self.env.log.debug('HubzeroDatabaseConnection::connect() end')
         return 0
 
